#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-06-03 15:16

import requests
import re
import random
import time


class MyRequest():

    def __init__(self):

        self.iplist = []
        html = requests.get("http://haoip.cc/tiqu.htm")
        iplistn = re.findall(r'r/>(.*?)<b', html.text, re.S)
        for ip in iplistn:
            i = re.sub('\n', '', ip)
            self.iplist.append(i.strip())
        self.user_agent_list = [
            "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/22.0.1207.1 Safari/537.1",
            "Mozilla/5.0 (X11; CrOS i686 2268.111.0) AppleWebKit/536.11 (KHTML, like Gecko) Chrome/20.0.1132.57 Safari/536.11",
            "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.6 (KHTML, like Gecko) Chrome/20.0.1092.0 Safari/536.6",
            "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.6 (KHTML, like Gecko) Chrome/20.0.1090.0 Safari/536.6",
            "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/19.77.34.5 Safari/537.1",
            "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.9 Safari/536.5",
            "Mozilla/5.0 (Windows NT 6.0) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.36 Safari/536.5",
            "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1063.0 Safari/536.3",
            "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1063.0 Safari/536.3",
            "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_0) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1063.0 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1062.0 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1062.0 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1061.1 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1061.1 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.1) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1061.1 Safari/536.3",
            "Mozilla/5.0 (Windows NT 6.2) AppleWebKit/536.3 (KHTML, like Gecko) Chrome/19.0.1061.0 Safari/536.3",
            "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.24 (KHTML, like Gecko) Chrome/19.0.1055.1 Safari/535.24",
            "Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/535.24 (KHTML, like Gecko) Chrome/19.0.1055.1 Safari/535.24"
        ]

    def get(self, url, params=None, timeout=3, proxy=True, num_retries=6):
        UA = random.choice(self.user_agent_list)
        headers = {'User-Agent': UA}

        if proxy:
            try:
                return requests.get(url=url, params=params, headers=headers, timeout=timeout)
            except:
                if num_retries > 0:
                    time.sleep(10)
                    print(u'获取网页出错，10S后将获取倒数第：', num_retries, u'次')
                    return self.get(url=url,params=params, timeout=timeout, num_retries=(num_retries - 1))
                else:
                    print(u'开始使用代理')
                    time.sleep(10)
                    IP = ''.join(str(random.choice(self.iplist)).strip())
                    proxy = {'http': IP}
                    return self.get(url=url, params=params, timeout=timeout, proxy=proxy, )
        else:
            try:
                ip = ''.join(
                    str(random.choice(self.iplist)).strip())
                proxy = {'http': ip}
                return requests.get(url=url, params=params, headers=headers, proxies=proxy, timeout=timeout)

            except:
                if num_retries > 0:
                    time.sleep(10)
                    IP = ''.join(str(random.choice(self.iplist)).strip())
                    proxy = {'http': IP}
                    print('正在更换代理，10S后将重新获取倒数第', num_retries, '次')
                    print('当前代理是：', proxy)
                    return self.get(url=url, params=params, timeout=timeout, proxy=proxy, num_retries=(num_retries - 1))
                else:
                    print(u'代理也不好使了！取消代理')
                    return self.get(url, timeout)


def main():
    my_request = MyRequest()
    respon = my_request.get('https://www.cnblogs.com/kayb/p/7225764.html')
    print(respon.text)


if __name__ == "__main__":
    main()












#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-06-02 12:29

import os
import openpyxl
from openpyxl.utils.exceptions import IllegalCharacterError


def write_json_excel(folder_path, file_name):

    if not os.path.exists(folder_path):
        print('folder {} not exists . '.format(folder_path))
        os.mkdir(folder_path)
        print('folder {} has created ! '.format(folder_path))
    else:
        pass

    work_book = openpyxl.Workbook()
    work_sheet = work_book.active

    title_is_none = True
    row_num = 1
    while True:

        json_item = yield
        if json_item is None:
            break

        # 写入字段名
        if title_is_none:
            for i, key in enumerate(json_item.keys()):
                work_sheet.cell(row=row_num, column=i+1, value=key)
            title_is_none = False
            row_num = row_num + 1
        else:
            pass
        # 写入字段
        for j, value in enumerate(json_item.values()):
            try:
                work_sheet.cell(row=row_num, column=j+1, value=value)
            except IllegalCharacterError as IErr:
                print('meet IllegalCharacterError, but pass.')
        row_num = row_num + 1

    file_path = ''.join([folder_path, '\\',file_name, '.xlsx'])
    work_book.save(file_path)
    print('file {} has created ! '.format(file_path))



def main():
    pass


if __name__ == "__main__":
    main()












#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-06-03 16:59

import re
import os
import json
import random
from ..unitl.getMd5 import get_md5_value
import time


def write_json(data,diretory_path, file_name=None):
    if not os.path.exists(diretory_path):
        print(''.join([diretory_path, 'not exits .']))
        os.mkdir(diretory_path)
        print(''.join([diretory_path, 'has been created !']))

    if not file_name:
        rstr = r"[\/\\\:\*\?\"\<\>\|]"
        file_name = re.sub(rstr, "_", file_name)
    else:
         file_name_string = ''.join([time.strftime('%X'), str(random.random())])
         file_name = get_md5_value(file_name_string)
    file_path = ''.join([diretory_path, file_name, '.json'])
    with open(file_path, 'w', encoding='utf-8') as json_file:
        json_file.write(json.dumps(data, indent=4, ensure_ascii=False))


def main():
    pass


if __name__ == "__main__":
    main()












#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-02-24 21:02
import datetime
import functools


def clockdeco(func):
    @functools.wraps(func)
    def wrapper(*args):
        start = datetime.datetime.now()
        result = func(*args)
        end = datetime.datetime.now()
        print('func : {} cunsumes {} second'.format(func.__name__, (end-start).seconds))
        return result
    return wrapper


@clockdeco
def sayhello():
    print("hello world!!")
















#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-06-02 12:38


import execjs
from samma1570.spiderTool.myRequest import MyRequest
import requests

class Py4Js():

    def __init__(self):
        self.ctx = execjs.compile(""" 
        function TL(a) { 
        var k = ""; 
        var b = 406644; 
        var b1 = 3293161072; 

        var jd = "."; 
        var $b = "+-a^+6"; 
        var Zb = "+-3^+b+-f"; 

        for (var e = [], f = 0, g = 0; g < a.length; g++) { 
            var m = a.charCodeAt(g); 
            128 > m ? e[f++] = m : (2048 > m ? e[f++] = m >> 6 | 192 : (55296 == (m & 64512) && g + 1 < a.length && 56320 == (a.charCodeAt(g + 1) & 64512) ? (m = 65536 + ((m & 1023) << 10) + (a.charCodeAt(++g) & 1023), 
            e[f++] = m >> 18 | 240, 
            e[f++] = m >> 12 & 63 | 128) : e[f++] = m >> 12 | 224, 
            e[f++] = m >> 6 & 63 | 128), 
            e[f++] = m & 63 | 128) 
        } 
        a = b; 
        for (f = 0; f < e.length; f++) a += e[f], 
        a = RL(a, $b); 
        a = RL(a, Zb); 
        a ^= b1 || 0; 
        0 > a && (a = (a & 2147483647) + 2147483648); 
        a %= 1E6; 
        return a.toString() + jd + (a ^ b) 
    }; 

    function RL(a, b) { 
        var t = "a"; 
        var Yb = "+"; 
        for (var c = 0; c < b.length - 2; c += 3) { 
            var d = b.charAt(c + 2), 
            d = d >= t ? d.charCodeAt(0) - 87 : Number(d), 
            d = b.charAt(c + 1) == Yb ? a >>> d: a << d; 
            a = b.charAt(c) == Yb ? a + d & 4294967295 : a ^ d 
        } 
        return a 
    } 
    """)

    def getTk(self, text):
        return self.ctx.call("TL", text)


my_request = MyRequest()


def translate(content, f, t):
    url_google = 'http://translate.google.cn/translate_a/single' \
                 '?client=t&dt=t&ie=UTF-8&oe=UTF-8&clearbtn=1&otf=1' \
                 '&pc=1&srcrom=0&ssel=0&tsel=0&kc=2'
    js = Py4Js()
    tk = js.getTk(content)
    values = {'tk': tk, 'q': content, 'sl': f, 'tl': t}
    response = requests.get(url=url_google, params=values)
    print(response.json())

    result_parts = list()
    for tran_sen in response[0]:
        result_parts.append(tran_sen[0])
    result = ''.join(result_parts)
    return result


if __name__ == '__main__':
    text_tran = translate('你好', 'ch-zn', 'en')










#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-02-24 21:23


def debugdeco(func):
    def wapper(*args, **kwargs):
        print("[DEBUG]:enter {}()".format(func.__name__))
        return func(*args, **kwargs)
    return wapper


@ debugdeco
def say(something):
    print("hello {}".format(something))















#   @author: 马朝威 1570858572@qq.com
#   @time: 2019-02-24 21:56

from os import listdir


def floderiterdeco(path):
    def wrapper(func):
        def inner(*args):
            file_names = listdir(path)
            for file_name in file_names:
                file_path = path+'//'+file_name
                with open(file_path,'r',encoding='utf-8') as f:
                    func(f)
        return inner
    return wrapper



@floderiterdeco('E:\\test')
def print_file_content(file):
    print(file.read())
    print('完成')















from setuptools import setup
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='samma1570',
    version='1.0.1',
    packages=setuptools.find_packages(),
    author='samma',
    author_email='1570858572@qq.com',
    description='the private tool of samma',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
       'openpyxl',
       'requests',
       'PyExecJS',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4'
    ],
)
